python-asdl
=================

Python (2.7 ~ 3.5) library containing the CPython 3.x ASDL parser, cleaned and
packaged here for convenience.


.. image:: https://travis-ci.org/fpoli/python-asdl.svg?branch=master
    :target: https://travis-ci.org/fpoli/python-asdl


Installation
------------

.. code-block:: bash

    $ pip install asdl


Usage
-----

.. code-block:: python

    import asdl
    print(asdl.parse("./test/Python.asdl"))


License
-------

Same as CPython: Python Software Foundation License (LICENSE file included
here).
